@@ -11,8 +11,7 @@ from .exceptions import ConnectionInterrupted
 import functools
 
 DJANGO_REDIS_IGNORE_EXCEPTIONS = getattr(settings,
-            'DJANGO_REDIS_IGNORE_EXCEPTIONS', False)
-
+            "DJANGO_REDIS_IGNORE_EXCEPTIONS", False)
 
 def omit_exception(method):
     """
@@ -22,15 +21,16 @@ def omit_exception(method):
     Note: this doesn't handle the `default` argument in .get().
     """
 
-    if not DJANGO_REDIS_IGNORE_EXCEPTIONS:
-        return method
-
     @functools.wraps(method)
     def _decorator(self, *args, **kwargs):
-        try:
+        if self._ignore_exceptions:
+            try:
+                return method(self, *args, **kwargs)
+            except ConnectionInterrupted:
+                return None
+        else:
             return method(self, *args, **kwargs)
-        except ConnectionInterrupted:
-            return None
+
     return _decorator
 
 
@@ -40,15 +40,12 @@ class RedisCache(BaseCache):
         self._server = server
         self._params = params
 
-        options = params.get('OPTIONS', {})
-        self._client_cls = options.get('CLIENT_CLASS', 'redis_cache.client.DefaultClient')
+        options = params.get("OPTIONS", {})
+        self._client_cls = options.get("CLIENT_CLASS", "redis_cache.client.DefaultClient")
         self._client_cls = load_class(self._client_cls)
         self._client = None
 
-        self._fallback_name = options.get('FALLBACK', None)
-        self._fallback = None
-        self._fallback_counter = 0
-        self._on_fallback = False
+        self._ignore_exceptions = options.get("IGNORE_EXCEPTIONS", DJANGO_REDIS_IGNORE_EXCEPTIONS)
 
     @property
     def client(self):
@@ -68,20 +65,6 @@ class RedisCache(BaseCache):
         """
         return self.client.get_client(write=True)
 
-    @property
-    def fallback_client(self):
-        """
-        Used in fallback mode on the primary client does not
-        connect to the server.
-        """
-
-        if self._fallback is None:
-            try:
-                self._fallback = get_cache(self._fallback_name)
-            except TypeError:
-                raise ImproperlyConfigured("%s cache backend is not configured" % (self._fallback_name))
-        return self._fallback
-
     @omit_exception
     def set(self, *args, **kwargs):
         return self.client.set(*args, **kwargs)
